==> keycloak-model-map-18.0.2-sources.jar: org/keycloak/models/map/group/MapGroupEntityFieldDelegate.java <==
package org.keycloak.models.map.group;
public class MapGroupEntityFieldDelegate extends org.keycloak.models.map.group.MapGroupEntity.AbstractGroupEntity implements org.keycloak.models.map.group.MapGroupEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> entityFieldDelegate;
    public MapGroupEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getParentId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.PARENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setParentId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.PARENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getGrantedRoles() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES);
    }
    @SuppressWarnings("unchecked") @Override public void setGrantedRoles(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addGrantedRole(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeGrantedRole(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/group/MapGroupEntityFieldDelegate.java <==
package org.keycloak.models.map.group;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapGroupEntityFieldDelegate extends org.keycloak.models.map.group.MapGroupEntity.AbstractGroupEntity implements org.keycloak.models.map.group.MapGroupEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> entityFieldDelegate;
    public MapGroupEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.group.MapGroupEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> getAttributes() {
        return (java.util.Map<String,java.util.List<String>>) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES);
    }
    @SuppressWarnings("unchecked") @Override public void setAttributes(java.util.Map<String,java.util.List<String>> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.List<String> getAttribute(String p0) {
        return (java.util.List<String>) entityFieldDelegate.mapGet(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setAttribute(String p0, java.util.List<String> p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0, p1);
    }
    @SuppressWarnings("unchecked") @Override public void removeAttribute(String p0) {
        entityFieldDelegate.mapRemove(org.keycloak.models.map.group.MapGroupEntityFields.ATTRIBUTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getName() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.NAME);
    }
    @SuppressWarnings("unchecked") @Override public void setName(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.NAME, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getParentId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.PARENT_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setParentId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.PARENT_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<String> getGrantedRoles() {
        return (java.util.Set<String>) entityFieldDelegate.get(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES);
    }
    @SuppressWarnings("unchecked") @Override public void setGrantedRoles(java.util.Set<String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addGrantedRole(String p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void removeGrantedRole(String p0) {
        entityFieldDelegate.collectionRemove(org.keycloak.models.map.group.MapGroupEntityFields.GRANTED_ROLES, p0);
    }
}
